This library parses hierarchic configuration files in a markdown inspired format.
Therefore the parse_config function is provided.
Enums
- Error
- Error if parsing fails.
Functions
- parse_
config - Parses the configuration file.
- parse_
config_ str - Parses configuration held in a string, sharing the core with
parse_configfor callers that already have the text in memory (for example a# Metablock extracted from a larger file).